@@ -106,6 +106,12 @@ class AkinonCloudClient:
         """
         return self._send_request("GET", "apps", params=qs)
 
+    def get_application(self, app_id: int):
+        """
+        Gets details of an application
+        """
+        return self._send_request("GET", "app_detail", params={"app_id": app_id})
+
     def create_application(self, data):
         return self._send_request("POST", "apps", data=data)
 
