@@ -51,9 +51,9 @@ class PublicKeys(Controller):
         }
         response = self.app.client.create_public_key(data)
         if response.is_succeed:
-            self.app.render({}, is_text=True, custom_text="Public Key added successfully.")
+            self.app.render({}, renderer_type='text', custom_text="Public Key added successfully.")
         else:
-            self.app.render({}, is_text=True, custom_text=response.data.get('non_field_errors') or response.data.get('public_key'))
+            self.app.render({}, renderer_type='text', custom_text=response.data.get('non_field_errors') or response.data.get('public_key'))
 
     @ex(
         help='Public Key Remove Command',
@@ -67,7 +67,7 @@ class PublicKeys(Controller):
     def remove(self):
         response = self.app.client.remove_public_key(self.app.pargs.id)
         if response.is_succeed:
-            self.app.render({}, is_text=True, custom_text="Public Key removed successfully.")
+            self.app.render({}, renderer_type='text', custom_text="Public Key removed successfully.")
         else:
-            self.app.render({}, is_text=True,
+            self.app.render({}, renderer_type='text',
                             custom_text=response.data.get('non_field_errors') or response.data)
