@@ -1,9 +1,10 @@
+import rich
 from cement.core.output import OutputHandler
 from rich.console import Console
-from rich.table import Table
-from rich.panel import Panel
-from rich import print as rich_print
 from rich.markup import escape
+from rich.panel import Panel
+from rich.table import Table
+
 
 class BaseRenderer:
     def __init__(self, *args, **kwargs):
@@ -29,10 +30,12 @@ class TableRenderer(BaseRenderer):
 
     def render(self, *args, **kwargs):
         headers = kwargs.get('headers')
+        column_kwargs = kwargs.get('column_kwargs', {})
+        table_kwargs = kwargs.get('table_kwargs', {})
         rows = kwargs.get('rows')
-        table = Table()
-        for column_header in headers.values():
-            table.add_column(column_header)
+        table = Table(expand=True, **table_kwargs)
+        for key, header in headers.items():
+            table.add_column(header, **column_kwargs.get(key, {}))
 
         for datum in rows:
             row = list()
@@ -69,18 +72,26 @@ class TextRenderer(BaseRenderer):
         print(text)
 
 
+class RichRenderer(BaseRenderer):
+    console = Console()
+
+    def render(self, *args, **kwargs):
+        self.console.print(*args, **kwargs)
+
+
 class PipelineLogRenderer(BaseRenderer):
     def render(self, *args, **kwargs):
         rows = kwargs.get('rows', [])
         if not rows:
-            rich_print(Panel("No log found."))
+            rich.print(Panel("No log found."))
         for row in rows:
-            rich_print(Panel(f'{escape(row.get("log_data"))}', title=f"[bold][red]{row.get('created_date')}[/]"))
+            rich.print(Panel(f'{escape(row.get("log_data"))}', title=f"[bold][red]{row.get('created_date')}[/]"))
 
 
 class AkinonOutputHandler(OutputHandler):
     renderers = {
         "text": TextRenderer,
+        "rich": RichRenderer,
         "realtime_log": RealtimeLogRenderer,
         "table": TableRenderer,
         "pipeline_log": PipelineLogRenderer
@@ -89,10 +100,9 @@ class AkinonOutputHandler(OutputHandler):
     class Meta:
         label = 'akinon_output_handler'
 
-    def render(self, data, *args, **kwargs):
-        renderer_type = kwargs.pop('renderer_type', 'table')
-        is_succeed = kwargs.pop('is_succeed', False)
+    def render(self, data, *args, renderer_type: str = 'table', is_succeed: bool = False, **kwargs):
+        kwargs.pop('template', None)
         if is_succeed or renderer_type == 'text':
-            self.renderers.get(renderer_type)(*args, **kwargs)
+            self.renderers.get(renderer_type)(data, *args, **kwargs)
         else:
             self.app.log.error(data)
